const {classes: Cc, interfaces: Ci, utils: Cu} = Components;
const {Services} = Cu.import('resource://gre/modules/Services.jsm', null);

var httpObserver = {
    classDescription: 'net-channel-event-sinks for 1319607@bugzilla.mozilla.org',
    classID: Components.ID('{dc8d6319-5f6e-4438-999e-53722db99e84}'),
    contractID: '@1319607@bugzilla.mozilla.org/net-channel-event-sinks;1',

    get componentRegistrar() {
        return Components.manager.QueryInterface(Ci.nsIComponentRegistrar);
    },

    get categoryManager() {
        return Cc['@mozilla.org/categorymanager;1']
                .getService(Ci.nsICategoryManager);
    },

    QueryInterface: (function() {
        var {XPCOMUtils} = Cu.import('resource://gre/modules/XPCOMUtils.jsm', null);
        return XPCOMUtils.generateQI([
            Ci.nsIFactory,
            Ci.nsIObserver,
            Ci.nsIChannelEventSink,
            Ci.nsISupportsWeakReference
        ]);
    })(),

    createInstance: function(outer, iid) {
        if ( outer ) {
            throw Components.results.NS_ERROR_NO_AGGREGATION;
        }
        return this.QueryInterface(iid);
    },

    register: function() {
        Services.obs.addObserver(this, 'http-on-modify-request', true);
        if ( this.componentRegistrar.isCIDRegistered(this.classID) ) {
            try {
                this.componentRegistrar.unregisterFactory(this.classID, Components.manager.getClassObject(this.classID, Ci.nsIFactory));
            } catch (ex) {
            }
        }
        this.componentRegistrar.registerFactory(
            this.classID,
            this.classDescription,
            this.contractID,
            this
        );
        this.categoryManager.addCategoryEntry(
            'net-channel-event-sinks',
            this.contractID,
            this.contractID,
            false,
            true
        );
    },

    unregister: function() {
        Services.obs.removeObserver(this, 'http-on-modify-request');
        this.componentRegistrar.unregisterFactory(this.classID, this);
        this.categoryManager.deleteCategoryEntry(
            'net-channel-event-sinks',
            this.contractID,
            false
        );
    },

    observe: function(channel, topic) {
        if ( channel instanceof Ci.nsIHttpChannel === false ) {
            return;
        }
        if ( channel.URI.asciiSpec === 'https://ton.twimg.com/tweetdeck-web/web/scripts/google_analytics.4a354c1e82.js' ) {
            channel.cancel(Components.results.NS_BINDING_ABORTED);
        }
    }
};

function startup(data/*, reason*/) {
    httpObserver.register();
}

function shutdown(data, reason) {
    if ( reason === APP_SHUTDOWN ) {
        return;
    }
    httpObserver.unregister();
}

function install(/*aData, aReason*/) {
}

function uninstall(aData, aReason) {
    if ( aReason !== ADDON_UNINSTALL ) {
        return;
    }
}
